use glyphon::TextArea;

use crate::{datastructs::RenderState, RenderInput};

use super::{fpsindicator::FpsIndicator, radar::Radar, status::Status};

pub struct UiManager {
	radar: Radar,
	status: Status,
	fps: FpsIndicator,
}

impl UiManager {
	pub fn new(state: &mut RenderState) -> Self {
		Self {
			radar: Radar::new(),
			status: Status::new(),
			fps: FpsIndicator::new(state),
		}
	}

	/// Draw all ui elements
	pub fn draw(&mut self, input: &RenderInput, state: &mut RenderState) {
		self.radar.draw(input, state);
		self.status.draw(input, state);
		self.fps.update(input, state);
	}

	pub fn get_textareas(&self) -> impl Iterator<Item = TextArea> {
		(0..1).map(|_| self.fps.get_textarea())
	}
}
